@@ -284,7 +284,11 @@ public class VisionGUI extends JFrame implements ActionListener, VisionUpdatedLi
 				setTitle("TekkotsuMon: Vision Raw");
 				isRaw=true;
 				isRLE=false;
-			}
+			} else if(args[i].toUpperCase().compareTo("REG")==0 || args[i]==String.valueOf(VisionListener.defRegionPort)) {
+				setTitle("TekkotsuMon: Vision Regions");
+				isRaw=false;
+				isRLE=true; //It's not really an RLE window, but the options are the same, so whatever
+			} 
 		}
 		vision.setMinimumSize(new Dimension(VisionListener.DEFAULT_WIDTH/2, VisionListener.DEFAULT_HEIGHT/2));
 		vision.setPreferredSize(new Dimension(VisionListener.DEFAULT_WIDTH*2, VisionListener.DEFAULT_HEIGHT*2));
